/*                            -----IsoEdit.c-----

Written by F.N.Zihlman
compiler: Turbo C V2.0

USAGE:  IsoEdit(x,y,VP2,data,tmin,tmax,buffer,VP3)

where:	* x and y are the cursor's x/y position of type int
	* VP2 is of data type WINDOW2
	* data is of data type TVDATA
	* tmin,tmax are the min/max times of type float
	* buffer is of data type void used to hold a captured screen
	  image
	* VP3 is of data type WINDOW3

function: capture and shift in time a time/velocity point from the
	  regional display

*/

#include <stdio.h>
#include <ctype.h>
#include <graphics.h>

#ifndef ISODEFSH
#define ISODEFSH 1
#include "isodefs.h"
#endif

#ifndef ISOWINDSH
#define ISOWINDSH 1
#include "isowinds.h"
#endif

#ifndef ISOTVH
#define ISOTVH 1
#include "isotv.h"
#endif



#define SHIFT_F4 87
#define U_ARRO   72
#define D_ARRO   80
#define U_10     85
#define D_10     68
#define SHFTU    56
#define SHFTD    50
#define BIGMOVE  10

float IsoNewT();	/* determine a new sample time */
void TVDisp();		/* time/velocity display       */

/* =================================================================== */
void IsoEdit(x,y,VP2,data,tmin,tmax,buffer,VP3)
int *x,*y;
WINDOW2 *VP2;
TVDATA *data;
float tmin,tmax;
void *buffer;
WINDOW3 *VP3;
{
  int ch=0,cirrad,mark,bkgrnd,frgrnd;
  int ylo,yhi,idy=-1,i,y1,y2;
  float to;
  char DFlag;

  cirrad=VP2->twth;
  mark=VP2->twth/2;
  bkgrnd=getbkcolor();
  frgrnd=getcolor();

  for(i=0;i<data->numread;i++)
  {
    y1=(int)((data->tv[i][0]-tmin)*(VP2->ymax-VP2->ymin)/
		  (tmax-tmin)+VP2->ymin)-(cirrad/2);
    y2=(int)((data->tv[i][0]-tmin)*(VP2->ymax-VP2->ymin)/
		  (tmax-tmin)+VP2->ymin)+(cirrad/2);
    if((*y>=y1)&&(*y<=y2))
    {
      idy=i;
      *y=(int)((data->tv[i][0]-tmin)*(VP2->ymax-VP2->ymin)/
		  (tmax-tmin)+VP2->ymin);
    }
  }

  if(idy>=0)
  {
    if(idy==0)
    {
      ylo=VP2->ymin;
      yhi=(int)((data->tv[idy+1][0]-tmin)*(VP2->ymax-VP2->ymin)/
		(tmax-tmin)+VP2->ymin)-mark-1;
    }
    else if(idy==data->numread-1)
    {
      ylo=(int)((data->tv[idy-1][0]-tmin)*(VP2->ymax-VP2->ymin)/
		(tmax-tmin)+VP2->ymin)+mark+1;
      yhi=VP2->ymax;
    }
    else
    {
      ylo=(int)((data->tv[idy-1][0]-tmin)*(VP2->ymax-VP2->ymin)/
		(tmax-tmin)+VP2->ymin)+mark+1;
      yhi=(int)((data->tv[idy+1][0]-tmin)*(VP2->ymax-VP2->ymin)/
		(tmax-tmin)+VP2->ymin)-mark-1;
    }

    getimage(*x-cirrad-1,*y-cirrad-1,*x+cirrad+1,*y+cirrad+1,
	     buffer);
    putimage(*x-cirrad-1,*y-cirrad-1,buffer,XOR_PUT);
    getimage(*x-cirrad-1,*y-cirrad-1,*x+cirrad+1,*y+cirrad+1,
	     buffer);
    circle(*x,*y,cirrad);

    VP3->vval=data->tv[idy][1];
    while(ch!=SHIFT_F4)
    {
      ch=toupper(getch());
      switch(ch)
      {
	case U_ARRO:
	  DFlag='u';
	  moveit(ylo,x,y,cirrad,buffer,DFlag);
	  VP3->tval=IsoNewT(*y,VP2->ymin,VP2->ymax,tmin,tmax);
	  TVDisp(VP3);
	  setviewport(VP2->x1,VP2->y1,VP2->x2,VP2->y2,1);
	  break;

	case SHFTU:
	case U_10:
	  DFlag='U';
	  moveit(ylo+BIGMOVE,x,y,cirrad,buffer,DFlag);
	  VP3->tval=IsoNewT(*y,VP2->ymin,VP2->ymax,tmin,tmax);
	  TVDisp(VP3);
	  setviewport(VP2->x1,VP2->y1,VP2->x2,VP2->y2,1);
	  break;

	case D_ARRO:
	  DFlag='d';
	  moveit(yhi,x,y,cirrad,buffer,DFlag);
	  VP3->tval=IsoNewT(*y,VP2->ymin,VP2->ymax,tmin,tmax);
	  TVDisp(VP3);
	  setviewport(VP2->x1,VP2->y1,VP2->x2,VP2->y2,1);
	  break;

	case SHFTD:
	case D_10:
	  DFlag='D';
	  moveit(yhi-BIGMOVE,x,y,cirrad,buffer,DFlag);
	  VP3->tval=IsoNewT(*y,VP2->ymin,VP2->ymax,tmin,tmax);
	  TVDisp(VP3);
	  setviewport(VP2->x1,VP2->y1,VP2->x2,VP2->y2,1);
	  break;

	case SHIFT_F4:
          setcolor(bkgrnd);
          circle(*x,*y,cirrad);
	  setcolor(frgrnd);
	  circle(*x,*y,mark);
	  getimage(*x-cirrad-1,*y-cirrad-1,*x+cirrad+1,
		   *y+cirrad+1,buffer);
	  circle(*x,*y,cirrad);
	  break;
      }
    }
    setviewport(VP3->x1,VP3->y1,VP3->x2,VP3->y2,1);
    clearviewport();
    setviewport(VP2->x1,VP2->y1,VP2->x2,VP2->y2,1);
    data->tv[idy][0]=IsoNewT(*y,VP2->ymin,VP2->ymax,tmin,tmax);
    if(data->tv[idy][0]<data->tmin)
      data->tmin=data->tv[idy][0];
    if(data->tv[idy][0]>data->tmax)
      data->tmax=data->tv[idy][0];
  }
}
