/*                          ----- IsoInput.c -----

Written by: F.N. Zihlman
Compiler: Turbo C V2.0

USAGE: status=IsoInput(ioparms,datain);

where: * status is the return status indicator of type integer,
       * ioparms is the data structure providing the user-suppiled info,
       * datain is an array of data structures with each holding individual
	 velocity functions having the following information:

		1) cdp location
		2) number of time/velocity pairs in the velocity function
		3) minimum & maximum time & velocity values in the velocity
		   function
		4) an array of the velocity function's time/velocity pairs

*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifndef ISODEFSH
#define ISODEFSH 1
#include "isodefs.h"
#endif

#ifndef ISOPARMSH
#define ISOPARMSH 1
#include "isoparms.h"
#endif

#ifndef ISOTVH
#define ISOTVH 1
#include "isotv.h"
#endif

int IsoRead();

FILE *infile;

/* ================================================================ */

int IsoInput(ioparms,datain)
PARAMETERS *ioparms;
TVDATA *datain;
{
  TVDATA iobuf;
  int i,j,incount,istat=TRUE,num;

  if((infile=fopen(ioparms->srcfl,"r"))==NULL)
  {
    printf("\n***ERROR OPENING %s***\n",ioparms->srcfl);
    printf("press any key to continue...\n");
    istat=FALSE;
    getch();
  }
  else
  {
    ioparms->gtmin=99999.;
    ioparms->gtmax=0.;
    ioparms->gvmin=99999.;
    ioparms->gvmax=0.;
    ioparms->vmin=99999.;
    ioparms->vmax=0.;
    if(ioparms->tstart<=-1.)
      ioparms->tmin=99999.;
    else
      ioparms->tmin=ioparms->tstart;

    if(ioparms->tend<=-1.)
      ioparms->tmax=0.0;
    else
      ioparms->tmax=ioparms->tend;

    ioparms->recsread=0;
    incount=0;

    /* -----START-------------------------------------------------- */

    while((istat==TRUE)&&(incount<MAXCDPS))
    {
      istat=IsoRead(&iobuf);

      if(istat==TRUE)
	if((atol(iobuf.id)>=atol(ioparms->cdp1))&&
	   (atol(iobuf.id)<=atol(ioparms->cdp2)))
	{
	  *datain=iobuf;

	  if(ioparms->tstart<=-1.)
	    if(ioparms->tmin>iobuf.tmin)
	      ioparms->tmin=iobuf.tmin;

	  if(ioparms->tend<=-1.)
	    if(ioparms->tmax<iobuf.tmax)
	      ioparms->tmax=iobuf.tmax;

	  if(ioparms->gvmin>iobuf.vmin)
	    ioparms->gvmin=iobuf.vmin;
	  if(ioparms->gvmax<iobuf.vmax)
	    ioparms->gvmax=iobuf.vmax;

	  for(i=0;i<iobuf.numread;i++)
	    if((iobuf.tv[i][0]>=ioparms->tmin)&&
	       (iobuf.tv[i][0]<=ioparms->tmax))
	    {
	      if(ioparms->vmin>iobuf.tv[i][1])
		ioparms->vmin=iobuf.tv[i][1];
	      if(ioparms->vmax<iobuf.tv[i][1])
		ioparms->vmax=iobuf.tv[i][1];
	    }

	  if(ioparms->gtmin>iobuf.tmin)
	    ioparms->gtmin=iobuf.tmin;
	  if(ioparms->gtmax<iobuf.tmax)
	    ioparms->gtmax=iobuf.tmax;

	  if(++incount<MAXCDPS)
	    datain++;
	  ioparms->recsread++;
	}
    }
    if(ioparms->recsread>=MAXCDPS)
      strcpy(ioparms->cdp2,datain->id);
    fclose(infile);

    if((istat==FALSE)&&(ioparms->recsread>0))
      istat=TRUE;

  }
  return(istat);
}
