/*                            -----IsoPlot.C-----

written by F.N. Zihlman
compiler: Turbo C V2.0

USAGE:	VP2Plot(&VP1,&VP2,&ioparms,&datain,ttlstr)

where:	* VP1 is the data structure for window 1
	* VP2 is the data structure defining window 2
	* ioparms is the data structure defining the I/O parameters
	* datain is thedata structure containing the input data
	* ttlstr is the title string for window 1

function: plot isovelocity lines on the regional display in window 2

*/


#include <stdio.h>
#include <graphics.h>

#ifndef ISODEFSH
#define IOSDEFSH 1
#include "isodefs.h"
#endif

#ifndef ISOPARMSH
#define IOSPARMSH 1
#include "isoparms.h"
#endif

#ifndef ISOWINDSH
#define IOSWINDSH 1
#include "isowinds.h"
#endif

#ifndef ISOTVH
#define IOSTVH 1
#include "isotv.h"
#endif

#define MAXISOS  200

extern int GraphDriver;
extern int GraphMode;

/* ------------------------------------------------------------------ */
void IsoPlot(VP1,VP2,ioparms,datain,ttlstr)
WINDOW1 *VP1;
WINDOW2 *VP2;
PARAMETERS *ioparms;
TVDATA  *datain;
char *ttlstr;
{
  char str[MAXTITLE];
  int cdp,pt,isoinc=100,isovel,isocount,isovmin,isovmax,done;
  int isotmin,isotmax;
  int isoy[MAXCDPS][MAXISOS],ind1,ind2,ind3,y1,y2,to,imode;
  int bcolor,fcolor;
  float v1,v2;

  bcolor=getbkcolor();
  fcolor=getcolor();

  isovmin=ioparms->isolo;
  if(isovmin<(int)ioparms->vmin)
    isovmin=(int)ioparms->vmin;
  isovmax=ioparms->isohi;
  if(isovmax>(int)ioparms->vmax)
    isovmax=(int)ioparms->vmax;
  isoinc=ioparms->isoinc;
  isocount=((isovmax-isovmin)/isoinc+1);
  if(isocount>MAXISOS)
    isocount=MAXISOS-1;

  for(cdp=0;cdp<ioparms->recsread;cdp++)
  {
    isovel=isovmin;
    done=FALSE;
    ind1=0;
    ind2=1;
    ind3=0;

    while(!done)
    {
      if(isovel<(int)(datain+cdp)->tv[ind1][1])
      {
	if(ind1==0)
	{
	  to=(int)((isovel-ioparms->vmin)/
		  ((datain+cdp)->tv[ind1][1]-ioparms->vmin)*
		  ((datain+cdp)->tv[ind1][0]-ioparms->tmin)+
		    ioparms->tmin);
	  if(to<(int)ioparms->tmin)
	    to=(int)ioparms->tmin;
	}
	else
	{
	  to=(int)((isovel-(datain+cdp)->tv[ind1-1][1])/
		  ((datain+cdp)->tv[ind1][1]-(datain+cdp)->tv[ind1-1][1])*
		  ((datain+cdp)->tv[ind1][0]-(datain+cdp)->tv[ind1-1][0])+
		  (datain+cdp)->tv[ind1-1][0] );
	}

	isoy[cdp][ind3++]=(int)((to-ioparms->tmin)*(VP2->ymax-VP2->ymin)/
			  (ioparms->tmax-ioparms->tmin)+VP2->ymin);
	isovel+=isoinc;
      }
      else if(isovel==(int)(datain+cdp)->tv[ind1][1])
      {
	isoy[cdp][ind3++]=(int)(((datain+cdp)->tv[ind1][0]-ioparms->tmin)*
			       (VP2->ymax-VP2->ymin)/
			       (ioparms->tmax-ioparms->tmin)+VP2->ymin);
	isovel+=isoinc;
      }
      else if((isovel>(int)(datain+cdp)->tv[ind1][1])&&
		(isovel<(int)(datain+cdp)->tv[ind2][1]))
      {
	to=(int)((isovel-(datain+cdp)->tv[ind1][1])/
		  ((datain+cdp)->tv[ind2][1]-(datain+cdp)->tv[ind1][1])*
		  ((datain+cdp)->tv[ind2][0]-(datain+cdp)->tv[ind1][0])+
		  (datain+cdp)->tv[ind1][0] );
	isoy[cdp][ind3++]=(int)((to-ioparms->tmin)*(VP2->ymax-VP2->ymin)/
				(ioparms->tmax-ioparms->tmin)+VP2->ymin);
	isovel+=isoinc;
      }
      else if(isovel==(int)(datain+cdp)->tv[ind2][1])
      {
	isoy[cdp][ind3++]=(int)(((datain+cdp)->tv[ind2][0]-ioparms->tmin)*
			       (VP2->ymax-VP2->ymin)/
			       (ioparms->tmax-ioparms->tmin)+VP2->ymin);
	isovel+=isoinc;
      }
      else if(isovel>(int)(datain+cdp)->tv[ind2][1])
	if(ind2>=(datain+cdp)->numread-1)
	{
	  to=(int)((isovel-(datain+cdp)->tv[ind2][1])/
		    (ioparms->vmax-(datain+cdp)->tv[ind2][1])*
		    (ioparms->tmax-(datain+cdp)->tv[ind2][0])+
		    (datain+cdp)->tv[ind2][0] );
	  if(to>(int)ioparms->tmax)
	    to=(int)ioparms->tmax;
	  isoy[cdp][ind3++]=(int)((to-ioparms->tmin)*(VP2->ymax-VP2->ymin)/
		            (ioparms->tmax-ioparms->tmin)+VP2->ymin);
	  isovel+=isoinc;
	}

      if((ind2<(datain+cdp)->numread-1)&&
	  (isovel>(int)(datain+cdp)->tv[ind2][1]))
      {
	  ind1++;
	  ind2++;
      }

      if((isovel>isovmax)||(ind3>=isocount))
	done=TRUE;
    }
  }
  setviewport(VP1->x1,VP1->y1,VP1->x2,VP1->y2,1);
  settextjustify(CENTER_TEXT,CENTER_TEXT);
  settextstyle(SMALL_FONT,HORIZ_DIR,MAGFACTOR);
  setcolor(bcolor);
  outtextxy(VP1->title1.tx,VP1->title1.ty,VP1->title1.titl);
  setcolor(fcolor);
  sprintf(ttlstr,"Min: %d         Max: %d         Inc: %d",isovmin,
	  isovmax,isoinc);
  outtextxy(VP1->title1.tx,VP1->title1.ty,ttlstr);
  setviewport(VP2->x1,VP2->y1,VP2->x2,VP2->y2,1);

  for(pt=0;pt<isocount;pt++)
    for(cdp=1;cdp<ioparms->recsread;cdp++)
    {
      y1=isoy[cdp-1][pt];
      y2=isoy[cdp][pt];
      if(y1<VP2->ymin)
	y1=VP2->ymin;
      if(y1>VP2->ymax)
	y1=VP2->ymax;
      if(y2<VP2->ymin)
	y2=VP2->ymin;
      if(y2>VP2->ymax)
	y2=VP2->ymax;

      line(VP2->xcoords[cdp-1],y1,VP2->xcoords[cdp],y2);
    }
}
                         /* -----End IsoPlot----- */
