/*                            -----Ved2Plot.C-----

written by F.N. Zihlman
compiler: Turbo C V2.0

USAGE:	VP2Plot(&Ved1,&Ved2,&datain)

where:	* Ved1 is the data structure defining window 1
	* Ved2 is the data structure defining window 2
	* datain is thedata structure containing the input data

function: set up and label windows 1 & 2 and display the data

*/

#include <stdio.h>
#include <graphics.h>

#ifndef ISODEFSH
#define ISODEFSH 1
#include "isodefs.h"
#endif

#ifndef VEDWINDSH
#define VEDWINDSH 1
#include "vedwinds.h"
#endif

#ifndef ISOTVH
#define ISOTVH 1
#include "isotv.h"
#endif

extern int GraphDriver;
extern int GraphMode;

/* ============================================================= */

void Ved2Plot(Ved1,Ved2,Data)
VEDPORT1 *Ved1;
VEDPORT2 *Ved2;
TVDATA   *Data;
{
  float dv,dt;
  int marker,savecolor;
  int i,v,x,t,y,x1,y1,x2,y2;
  struct linesettingstype lineinfo;

  dt=Data->tmax-Data->tmin;
  dv=Data->vmax-Data->vmin;
  marker=Ved2->thgt/2;

  /* -----Reset time/velocity axes labels------------------------ */
  savecolor=getcolor();
  setcolor(getbkcolor());
  setviewport(Ved1->x1,Ved1->y1,Ved1->x2,Ved1->y2,1);
  settextjustify(CENTER_TEXT,CENTER_TEXT);
  settextstyle(SMALL_FONT,HORIZ_DIR,MAGFACTOR);
  outtextxy(Ved1->xaxis.pt1x,Ved1->xaxis.pt1y,Ved1->xaxis.pt1);
  outtextxy(Ved1->xaxis.pt2x,Ved1->xaxis.pt2y,Ved1->xaxis.pt2);
  settextjustify(LEFT_TEXT,CENTER_TEXT);
  outtextxy(Ved1->yaxis.pt1x,Ved1->yaxis.pt1y,Ved1->yaxis.pt1);
  outtextxy(Ved1->yaxis.pt2x,Ved1->yaxis.pt2y,Ved1->yaxis.pt2);
  sprintf(Ved1->xaxis.pt1,"%5.0f",Data->vmin);
  sprintf(Ved1->xaxis.pt2,"%5.0f",Data->vmax);
  sprintf(Ved1->yaxis.pt1,"%5.0f",Data->tmin);
  sprintf(Ved1->yaxis.pt2,"%5.0f",Data->tmax);
  setcolor(savecolor);
  settextjustify(CENTER_TEXT,CENTER_TEXT);
  outtextxy(Ved1->xaxis.pt1x,Ved1->xaxis.pt1y,Ved1->xaxis.pt1);
  outtextxy(Ved1->xaxis.pt2x,Ved1->xaxis.pt2y,Ved1->xaxis.pt2);
  settextjustify(LEFT_TEXT,CENTER_TEXT);
  outtextxy(Ved1->yaxis.pt1x,Ved1->yaxis.pt1y,Ved1->yaxis.pt1);
  outtextxy(Ved1->yaxis.pt2x,Ved1->yaxis.pt2y,Ved1->yaxis.pt2);

  /* -----Set up viewport 2------------------------------------- */
  setviewport(Ved2->x1,Ved2->y1,Ved2->x2,Ved2->y2,1);
  clearviewport();

  /* =====DISPLAY DATA============================================ */

  getlinesettings(&lineinfo);
  setlinestyle(DOTTED_LINE,0,NORM_WIDTH);
  for(i=0;i<=Data->numread-1;i++)
  {
    if(i<=0)
    {
      x1=(int)((Data->tv[i][1]-Data->vmin)*(Ved2->xmax-Ved2->xmin)/dv+Ved2->xmin);
      if(x1>Ved2->xmax)
        x1=Ved2->xmax;
      y1=(int)((Data->tv[i][0]-Data->tmin)*(Ved2->ymax-Ved2->ymin)/dt+Ved2->ymin);
      if(y1>Ved2->ymax)
        y1=Ved2->ymax;
    }

    x2=(int)((Data->tv[i][1]-Data->vmin)*(Ved2->xmax-Ved2->xmin)/dv+Ved2->xmin);
    if(x2>Ved2->xmax)
      x2=Ved2->xmax;
    y2=(int)((Data->tv[i][0]-Data->tmin)*(Ved2->ymax-Ved2->ymin)/dt+Ved2->ymin);
    if(y1>Ved2->ymax)
      y1=Ved2->ymax;
    line(x1,y1,x2,y2);
    circle(x2,y2,marker);
    y1=y2;
    x1=x2;
  }
  setlinestyle(lineinfo.linestyle,lineinfo.upattern,lineinfo.thickness);
}                   /* -----Ved2Plot----- */