/* 			 ----- IsoVpSet.c -----

Written by F.N. Zihlman
Compiler: Turbo C V2.0

USAGE: IsoVpSet(&datain,&Ved1,&Ved2);

where: * datain is the array of data structures for the velocity functions
       * Ved1 and Ved2 are the data structures which define the two graphics
	 windows of the displays.

function: initialization of the two graphics windows, or "view ports",
	  used to display/edit individual velocity functions
*/

#include <stdio.h>
#include <dos.h>
#include <graphics.h>
#include <math.h>
#include <string.h>

#ifndef ISODEFSH
#define ISODEFSH 1
#include "isodefs.h"
#endif

#ifndef ISOTVH
#define ISOTVH 1
#include "isotv.h"
#endif

#ifndef VEDWINDSH
#define VEDWINDSH 1
#include "vedwinds.h"
#endif

#define XORIGIN 7
#define YORIGIN 5

extern int GraphDriver,GraphMode;

/* ============================================================== */

void VedVpSet(datain,Ved1,Ved2)
TVDATA     *datain;
VEDPORT1    *Ved1;
VEDPORT2    *Ved2;
{

  struct linesettingstype Ved1lines;
  struct date pdate;
  struct time ptime;
  char dstr[30],tstr[30],stuff[30];
  int i;



  setviewport(Ved1->x1,Ved1->y1,Ved1->x2,Ved1->y2,1);

  settextstyle(SMALL_FONT,HORIZ_DIR,MAGFACTOR);
  settextjustify(CENTER_TEXT,CENTER_TEXT);

  getviewsettings(&Ved1->VPort);
  getlinesettings(&Ved1lines);

  Ved1->x1=0;                                       /* Ved1 GLOBAL VALUES */
  Ved1->y1=0;
  Ved1->x2=getmaxx();
  Ved1->y2=getmaxy();
  Ved1->thgt=textheight("Z");
  Ved1->twidth=textwidth("Z");


  Ved1->boxx1=XORIGIN*Ved1->twidth-Ved1lines.thickness;   /* Ved1 BOX VALUES */
  Ved1->boxy1=YORIGIN*Ved1->thgt-Ved1lines.thickness;
  Ved1->boxx2=(getmaxx()-(2*Ved1->twidth))+Ved1lines.thickness;
  Ved1->boxy2=(getmaxy()-(2*Ved1->thgt))+Ved1lines.thickness;

  strcpy(Ved1->xaxis.label,"Velocity");       /* AXES LABELS */
  Ved1->xaxis.lx=(Ved1->boxx2-Ved1->boxx1)/2+Ved1->boxx1;
  Ved1->xaxis.ly=Ved1->boxy1-(2*Ved1->twidth);
  strcpy(Ved1->yaxis.label,"Time (ms)");
  Ved1->yaxis.lx=Ved1->boxx1-(2*Ved1->thgt);
  Ved1->yaxis.ly=(Ved1->boxy2-Ved1->boxy1)/2+Ved1->boxy1;

  sprintf(Ved1->xaxis.pt1,"%5.0f",datain->vmin);  	  /* BOX      */
  Ved1->xaxis.pt1x=(XORIGIN*Ved1->twidth)+Ved1->twidth+2; /* LOCATION */
  Ved1->xaxis.pt1y=Ved1->xaxis.ly;                        /* LABELS   */
  sprintf(Ved1->xaxis.pt2,"%5.0f",datain->vmax);
  Ved1->xaxis.pt2x=Ved1->boxx2-Ved1->twidth-2;
  Ved1->xaxis.pt2y=Ved1->xaxis.pt1y;

  sprintf(Ved1->yaxis.pt1,"%5.0f",datain->tmin);   /* BOX TIME LABELS */
  Ved1->yaxis.pt1x=(XORIGIN-(strlen(Ved1->yaxis.pt1))-1)*Ved1->twidth;
  Ved1->yaxis.pt1y=(Ved1->boxy1+Ved1lines.thickness)+Ved1->thgt;
  sprintf(Ved1->yaxis.pt2,"%5.0f",datain->tmax);
  Ved1->yaxis.pt2x=(XORIGIN-(strlen(Ved1->yaxis.pt2))-1)*Ved1->twidth;
  Ved1->yaxis.pt2y=(Ved1->boxy2-Ved1lines.thickness)-Ved1->thgt;

  Ved1->xaxis.tic1x=Ved1->xaxis.pt1x;                    /* BOX TICK MARKS */
  Ved1->xaxis.tic1y=Ved1->xaxis.pt1y+Ved1->thgt;
  Ved1->xaxis.tic2x=Ved1->xaxis.pt2x;
  Ved1->xaxis.tic2y=Ved1->xaxis.tic1y;

  Ved1->yaxis.tic1x=6*Ved1->twidth;
  Ved1->yaxis.tic1y=Ved1->yaxis.pt1y;
  Ved1->yaxis.tic2x=Ved1->yaxis.tic1x;
  Ved1->yaxis.tic2y=Ved1->yaxis.pt2y;

  getdate(&pdate);                                 /* Ved1 DISPLAY TITLES */
  gettime(&ptime);
  sprintf(dstr,"%d %d %d",pdate.da_mon,pdate.da_day,pdate.da_year);
  sprintf(tstr,"%02d:%02d:%02d.%02d",ptime.ti_hour,ptime.ti_min,ptime.ti_sec,ptime.ti_hund);
  strcat((strcat((strcpy(Ved1->title1.titl,dstr)),
	" * Interactive Velocity Edit V0.2 * ")),tstr);
  Ved1->title1.tx=Ved1->xaxis.lx;
  Ved1->title1.ty=Ved1->thgt/2;
  Ved1->title2.tx=Ved1->title1.tx;
  Ved1->title2.ty=Ved1->y2-Ved1->thgt;

  Ved2->x1=Ved1->boxx1+Ved1lines.thickness;           /* Ved2 SETUP */
  Ved2->y1=Ved1->boxy1+Ved1lines.thickness;
  Ved2->x2=Ved1->boxx2-Ved1lines.thickness;
  Ved2->y2=Ved1->boxy2-Ved1lines.thickness;
  setviewport(Ved2->x1,Ved2->y1,Ved2->x2,Ved2->y2,1);
  getviewsettings(&Ved2->VPort);

					 /* Ved2 PLOTTING MIN/MAX VALUES */
  Ved2->xmin=Ved1->xaxis.tic1x-Ved2->x1-1;
  Ved2->ymin=Ved1->yaxis.tic1y-Ved2->y1+1;
  Ved2->xmax=Ved1->xaxis.tic2x-Ved2->x1-1;
  Ved2->ymax=Ved1->yaxis.tic2y-Ved2->y1+1;
  Ved2->thgt=Ved1->thgt;
  Ved2->twth=Ved1->twidth;

}                    /* -----end VedVpSet----- */